@@ -16,7 +16,7 @@
 sim_factor2 <- function(n, levels, var_level = 1, replace = TRUE,
                        ...) {
   if(var_level == 1) {
-    cat_var <- base::sample(x = levels, size = n[['level1']], 
+    cat_var <- base::sample(x = levels, size = sum(n[['level1']]), 
                             replace = replace, ...)
   } else {
     if(var_level == 2) {
@@ -284,7 +284,12 @@ simulate_fixed <- function(data, sim_args, ...) {
     Xmat <- dplyr::bind_cols(Xmat, Omat)
   } else {
     Xmat <- data.frame(model.matrix(fixed_formula, Xmat, ...))
-    colnames(Xmat)[2:ncol(Xmat)] <- fixed_vars
+    
+    if(grepl("^0", as.character(fixed_formula)[2])) {
+      colnames(Xmat)[1:ncol(Xmat)] <- fixed_vars
+    } else {
+      colnames(Xmat)[2:ncol(Xmat)] <- fixed_vars
+    }
   }
   
   if(is.null(data)) {
